@@ -1,19 +1,19 @@
 # -*- coding: utf-8 -*-
-#    Copyright (C) 2012  Christian Ledermann
+# Copyright (C) 2012  Christian Ledermann
 #
-#    This library is free software; you can redistribute it and/or
-#    modify it under the terms of the GNU Lesser General Public
-#    License as published by the Free Software Foundation; either
-#    version 2.1 of the License, or (at your option) any later version.
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
 #
-#    This library is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#    Lesser General Public License for more details.
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
 #
-#    You should have received a copy of the GNU Lesser General Public
-#    License along with this library; if not, write to the Free Software
-#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 
 """
 With the launch of Google Earth 5.0, Google has provided extensions to KML
@@ -76,9 +76,6 @@ located at http://developers.google.com/kml/schema/kml22gx.xsd.
 import logging
 logger = logging.getLogger('fastkml.gx')
 
-from .config import etree
-from .config import GXNS as NS
-from .config import LXML
-
-
-
+# from .config import etree
+# from .config import GXNS as NS
+# from .config import LXML
